@@ -1,13 +1,14 @@
 import time
+from importlib import metadata
 from typing import Mapping
 
 from celery import Celery
-from celery import __version__ as celery_version
 from celery.signals import before_task_publish
 
 from judoscale.celery.collector import CeleryMetricsCollector
 from judoscale.core.adapter import Adapter, AdapterInfo
 from judoscale.core.config import config as judoconfig
+from judoscale.core.logger import logger
 from judoscale.core.reporter import reporter
 
 
@@ -20,10 +21,15 @@ def judoscale_celery(celery: Celery, extra_config: Mapping = {}) -> None:
     celery.conf.task_send_sent_event = True
 
     judoconfig.update(extra_config)
+
+    if not judoconfig.is_enabled:
+        logger.info("Not activated - no API URL provided")
+        return
+
     collector = CeleryMetricsCollector(config=judoconfig, broker=celery)
     adapter = Adapter(
         identifier="judoscale-celery",
-        adapter_info=AdapterInfo(platform_version=celery_version),
+        adapter_info=AdapterInfo(platform_version=metadata.version("celery")),
         metrics_collector=collector,
     )
 
