@@ -1,7 +1,9 @@
 import json
 import time
+from datetime import datetime
+from collections import defaultdict
 from threading import Thread
-from typing import List, Optional, Set
+from typing import List, Optional, Set, Tuple
 
 from celery import Celery
 from kombu import Connection
@@ -16,6 +18,7 @@ DEFAULTS = {
     "ENABLED": True,
     "MAX_QUEUES": 20,
     "QUEUES": [],
+    "TRACK_BUSY_JOBS": False,
 }
 
 
@@ -47,7 +50,7 @@ class CeleryMetricsCollector(JobMetricsCollector):
     def __init__(self, config: Config, broker: Celery):
         super().__init__(config=config)
 
-        self.config["CELERY"] = {**DEFAULTS, **self.config.get("RQ", {})}
+        self.config["CELERY"] = {**DEFAULTS, **self.config.get("CELERY", {})}
 
         self.broker = broker
         connection = self.broker.connection_for_read()
@@ -63,17 +66,25 @@ class CeleryMetricsCollector(JobMetricsCollector):
                 "Unsupported Redis server version. Minimum Redis version is 6.0."
             )
 
+        if self.adapter_config["TRACK_BUSY_JOBS"]:
+            self.inspect = broker.control.inspect(connection=connection)
+
         self._celery_queues: Set[str] = set()
         self.task_sent_handler = TaskSentHandler(self, connection)
         logger.debug(f"Redis is at {self.redis.connection_pool}")
 
         system_queues = {"unacked", "unacked_index"}
-        user_queues = {
-            q.decode("utf-8") if type(q) is bytes else q
-            for q in self.redis.scan_iter(match="[^_]*", _type="list")
-        }
-        logger.debug(f"Found initial queues: {list(user_queues)}")
-        self._celery_queues = user_queues - system_queues
+        for q in self.redis.scan_iter(_type="list"):
+            queue_name = q.decode() if isinstance(q, bytes) else q
+            if (
+                queue_name in system_queues
+                or queue_name.startswith("_kombu")
+                or queue_name.endswith("celery.pidbox")
+            ):
+                continue
+            self._celery_queues.add(queue_name)
+
+        logger.debug(f"Found initial queues: {list(self._celery_queues)}")
         self.task_sent_handler.start()
 
     @property
@@ -89,15 +100,38 @@ class CeleryMetricsCollector(JobMetricsCollector):
     def _queues(self) -> List[str]:
         return list(self._celery_queues)
 
-    def oldest_task(self, queue: str) -> Optional[dict]:
+    def oldest_task_and_timestamp(
+        self, queue: str
+    ) -> Optional[Tuple[dict, Optional[float]]]:
         """
-        Get the oldest task from the queue.
+        Get the oldest task from the queue, alongside the timestamp to be used for latency.
+
+        When a task contains no `eta`, we use the `published_at` timestamp we inject;
+        When a task contains a past `eta`, we use it instead of `published_at`;
+        When a task contains a future `eta`, we skip that task and continue looking through tasks in the queue.
         """
         try:
-            if payload := self.redis.lindex(queue, -1):
-                return json.loads(payload)
+            last_index = -1
+            now = time.time()
+
+            while payload := self.redis.lindex(queue, last_index):
+                payload = json.loads(payload)
+
+                if eta := payload.get("headers", {}).get("eta"):
+                    eta = datetime.fromisoformat(eta).timestamp()
+
+                    if eta <= now:
+                        return payload, eta
+                    else:
+                        last_index = last_index - 1
+                elif published_at := payload.get("properties", {}).get("published_at"):
+                    return payload, published_at
+                else:
+                    return payload, None
+
         except Exception as e:
             logger.warning(f"Unable to get a task from queue: {queue}", exc_info=e)
+
         return None
 
     def collect(self) -> List[Metric]:
@@ -105,12 +139,30 @@ class CeleryMetricsCollector(JobMetricsCollector):
         if not self.should_collect:
             return metrics
 
+        if self.adapter_config["TRACK_BUSY_JOBS"]:
+            busy_counts = defaultdict(lambda: 0)
+            if workers_tasks := self.inspect.active():
+                for active_tasks in workers_tasks.values():
+                    for task in active_tasks:
+                        busy_counts[task["delivery_info"]["routing_key"]] += 1
+
+            for queue in self.queues:
+                count = busy_counts[queue]
+                metrics.append(Metric.for_busy_queue(queue_name=queue, busy_jobs=count))
+
         logger.debug(f"Collecting metrics for queues {list(self.queues)}")
         for queue in self.queues:
-            if task := self.oldest_task(queue):
-                if published_at := task["properties"].get("published_at"):
+            if result := self.oldest_task_and_timestamp(queue):
+                task, timestamp = result
+                if timestamp:
                     metrics.append(
-                        Metric.for_queue(queue_name=queue, oldest_job_ts=published_at)
+                        Metric.for_queue(queue_name=queue, oldest_job_ts=timestamp)
+                    )
+                else:
+                    task_id = task.get("id", None)
+                    logger.warning(
+                        "Unable to find `published_at` in task properties for "
+                        f"task ID {task_id} in queue {queue}."
                     )
             else:
                 metrics.append(
