@@ -33,7 +33,7 @@ class Metric:
     timestamp: float  # Unix timestamp in fractional seconds
     value: int
     queue_name: Optional[str] = None
-    measurement: str = "queue_time"
+    measurement: str = "qt"
 
     @property
     def as_tuple(self) -> Tuple[int, int, str, Optional[str]]:
@@ -92,6 +92,29 @@ class Metric:
         logger.debug(f"queue_time={metric.value}ms")
         return metric
 
+    @classmethod
+    def for_web_app_time(cls, start: float, end: float = None):
+        """
+        Calculate the elapsed time in milliseconds from the given `start`,
+        log and return the app time Metric instance.
+
+        start:
+            The request start time, using monotonic time: `time.monotonic()`
+        """
+        if end == None:
+            end = time.monotonic()
+        app_time = int((end - start) * 1000)
+        logger.debug(f"app_time={app_time}ms")
+        return Metric(measurement="at", value=app_time, timestamp=time.time())
+
+    @classmethod
+    def for_web_utilization_pct(cls, utilization_pct: int):
+        """
+        Log and return Metric instance for utilization percentage
+        """
+        logger.debug(f"utilization_pct={utilization_pct}")
+        return Metric(measurement="up", value=utilization_pct, timestamp=time.time())
+
     @classmethod
     def for_queue(cls, queue_name: str, oldest_job_ts: float) -> "Metric":
         """
@@ -107,3 +130,24 @@ class Metric:
         metric = Metric.new(start_ms=int(oldest_job_ts * 1000), queue_name=queue_name)
         logger.debug(f"queue_name={queue_name}, queue_time={metric.value}ms")
         return metric
+
+    @classmethod
+    def for_busy_queue(cls, queue_name: str, busy_jobs: int) -> "Metric":
+        """
+        Log and return a Metric instance for the number of jobs being processed
+        for a given queue.
+
+        queue_name:
+            The name of the queue.
+
+        busy_jobs:
+            The number of jobs being processed for the given queue.
+        """
+        metric = Metric(
+            measurement="busy",
+            queue_name=queue_name,
+            value=busy_jobs,
+            timestamp=time.time(),
+        )
+        logger.debug(f"queue_name={queue_name}, busy_jobs={metric.value}")
+        return metric
